@@ -1,6 +1,6 @@
 `yaml.load` <-
 function(string, as.named.list = TRUE, handlers = NULL, error.label = NULL,
-         eval.expr = getOption("yaml.eval.expr", TRUE),
+         eval.expr = getOption("yaml.eval.expr", FALSE),
          merge.precedence = c("order", "override"), merge.warning = FALSE) {
 
   string <- enc2utf8(paste(string, collapse = "\n"))
